==> owncloud-10.0.3.tgz: owncloud/lib/l10n/ro.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nu se poate scrie în folderul \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Aceasta se poate repara de obicei prin permiterea accesului de scriere la dosarul de configurare al serverului Web",
    "See %s" : "Vezi %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Aceasta se poate repara de obicei de %s prin acordarea accesului de scriere către serverul Web pentru directorul de configurare %s. ",
    "Sample configuration detected" : "A fost detectată o configurație exemplu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S-a detectat copierea configurației exemplu. Acest lucru poate duce la oprirea instanței tale și nu este suportat. Te rugăm să citești documentația înainte de a face modificări în fișierul config.php",
    "PHP %s or higher is required." : "Versiunea PHP %s sau mai mare este necesară.",
    "PHP with a version lower than %s is required." : "Este necesară o versiune PHP mai mică decât %s",
    "%sbit or higher PHP required." : "Este necesar PHP %sbit sau mai mare.",
    "Following databases are supported: %s" : "Următoarele baze de date sunt suportate: %s",
    "The command line tool %s could not be found" : "Unealta în linie de comandă %s nu a fost găsită",
    "The library %s is not available." : "Biblioteca %s nu este disponibilă.",
    "Following platforms are supported: %s" : "Sunt suportate următoarele platforme: %s",
    "ownCloud %s or higher is required." : "ownCloud %s sau mai mare este necesar.",
    "ownCloud %s or lower is required." : "Versiunea ownCloud %s sau mai joasă este necesară.",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "today" : "astăzi",
    "yesterday" : "ieri",
    "_%n day ago_::_%n days ago_" : ["Acum o zi","Acum %n zile","Acum %n zile"],
    "last month" : "ultima lună",
    "_%n month ago_::_%n months ago_" : ["%n lună în urmă","%n luni în urmă","%n luni în urmă"],
    "last year" : "ultimul an",
    "_%n year ago_::_%n years ago_" : ["%n an în urmă","%n ani în urmâ","%n ani în urmâ"],
    "seconds ago" : "secunde în urmă",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulul cu id-ul %s nu există. Activează-l în setările tale de aplicație sau contactează-ți administratorul.",
    "Builtin" : "Inclus",
    "None" : "Niciuna",
    "Username and password" : "Nume de utilizator și parolă",
    "Username" : "Utilizator",
    "Password" : "Parolă",
    "Empty filename is not allowed" : "Nu este permis fișier fără nume",
    "Dot files are not allowed" : "Fișierele care încep cu caracterul punct nu sunt permise",
    "4-byte characters are not supported in file names" : "Caracterele stocate în 4 octeți nu sunt suportate în denumirile fișierelor",
    "File name is a reserved word" : "Numele fișierului este un cuvânt rezervat",
    "File name contains at least one invalid character" : "Numele fișierului conține măcar un caracter invalid",
    "File name is too long" : "Numele fișierului este prea lung",
    "App directory already exists" : "Directorul de aplicație există deja",
    "Can't create app folder. Please fix permissions. %s" : "Nu se poate crea directorul de aplicație. Repară permisiunile. %s",
    "Archive does not contain a directory named %s" : "Arhiva nu conține vreun director cu numele %s",
    "No source specified when installing app" : "Nu a fost specificată vreo sursă la instalarea aplicației",
    "No href specified when installing app from http" : "Nu s-a specificat adresa la instalarea aplicației dintr-o sursă de pe Internet",
    "No path specified when installing app from local file" : "Nu s-a specificat vreo cale la instalarea aplicației de pe un fișier local",
    "Archives of type %s are not supported" : "Arhivele de tip %s nu sunt suportate",
    "Failed to open archive when installing app" : "Deschiderea arhivei a eșuat în timpul instalării aplicației",
    "App does not provide an info.xml file" : "Aplicația nu furnizează un fișier info.xml",
    "App cannot be installed because appinfo file cannot be read." : "Aplicația nu poate fi instalată deoarece fișierul appinfo nu poate fi citit",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Semnătura nu a putut fi verificată. Contactează dezvoltatorul aplicației și verifică-ți consola administrativă.",
    "App can't be installed because of not allowed code in the App" : "Aplicația nu poate fi instalată deoarece conține cod nepermis",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplicația nu poate fi instalată deoarece nu este compatibilă cu această versiune ownCloud",
    "Apps" : "Aplicații",
    "General" : "General",
    "Storage" : "Stocare",
    "Security" : "Securitate",
    "Encryption" : "Încriptare",
    "Sharing" : "Partajare",
    "Search" : "Căutare",
    "Updates" : "Actualizări",
    "%s enter the database username and name." : "%s introdu numele de utilizator și parola pentru baza de date.",
    "%s enter the database username." : "%s introdu utilizatorul bazei de date.",
    "%s enter the database name." : "%s introduceți numele bazei de date",
    "Oracle connection could not be established" : "Conexiunea Oracle nu a putut fi stabilită",
    "Oracle username and/or password not valid" : "Numele de utilizator sau / și parola Oracle nu sunt valide",
    "DB Error: \"%s\"" : "Eroare Bază de Date: \"%s\"",
    "Offending command was: \"%s\"" : "Comanda cauză a fost: \"%s\"",
    "PostgreSQL username and/or password not valid" : "Nume utilizator și/sau parolă PostgreSQL greșită",
    "For the best results, please consider using a GNU/Linux server instead." : "Pentru cele mai bune rezultate, ia în calcul folosirea unui server care rulează un sistem de operare GNU/Linux.",
    "Set an admin username." : "Setează un nume de administrator.",
    "Set an admin password." : "Setează o parolă de administrator.",
    "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
    "%s shared »%s« with you" : "%s Partajat »%s« cu tine de",
    "%s via %s" : "%s via %s",
    "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
    "Sharing %s failed, because this item is already shared with %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu %s",
    "Not allowed to create a federated share with the same user" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Partajarea %s a eşuat, nu pot găsi %s, poate serverul nu poate fi contactat.",
    "Share type %s is not valid for %s" : "Tipul partajării %s nu este valid pentru %s",
    "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "The username is already being used" : "Numele de utilizator este deja folosit",
    "Help" : "Ajutor",
    "Settings" : "Setări",
    "Users" : "Utilizatori",
    "web services under your control" : "servicii web controlate de tine",
    "Application is not enabled" : "Aplicația nu este activată",
    "Authentication error" : "Eroare la autentificare",
    "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
    "Unknown user" : "Utilizator necunoscut",
    "Cannot write into \"config\" directory" : "Nu se poate scrie în folderul \"config\"",
    "Cannot write into \"apps\" directory" : "Nu se poate scrie în folderul \"apps\"",
    "PHP module %s not installed." : "Modulul PHP %s nu este instalat.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
    "PostgreSQL >= 9 required" : "Este necesară versiunea 9 sau mai mare a PostgreSQL",
    "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/ro.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nu se poate scrie în folderul \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Aceasta se poate repara de obicei prin permiterea accesului de scriere la dosarul de configurare al serverului Web",
    "See %s" : "Vezi %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Aceasta se poate repara de obicei de %s prin acordarea accesului de scriere către serverul Web pentru directorul de configurare %s. ",
    "Sample configuration detected" : "A fost detectată o configurație exemplu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S-a detectat copierea configurației exemplu. Acest lucru poate duce la oprirea instanței tale și nu este suportat. Te rugăm să citești documentația înainte de a face modificări în fișierul config.php",
    "PHP %s or higher is required." : "Versiunea PHP %s sau mai mare este necesară.",
    "PHP with a version lower than %s is required." : "Este necesară o versiune PHP mai mică decât %s",
    "%sbit or higher PHP required." : "Este necesar PHP %sbit sau mai mare.",
    "Following databases are supported: %s" : "Următoarele baze de date sunt suportate: %s",
    "The command line tool %s could not be found" : "Unealta în linie de comandă %s nu a fost găsită",
    "The library %s is not available." : "Biblioteca %s nu este disponibilă.",
    "Following platforms are supported: %s" : "Sunt suportate următoarele platforme: %s",
    "ownCloud %s or higher is required." : "ownCloud %s sau mai mare este necesar.",
    "ownCloud %s or lower is required." : "Versiunea ownCloud %s sau mai joasă este necesară.",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "today" : "astăzi",
    "yesterday" : "ieri",
    "_%n day ago_::_%n days ago_" : ["Acum o zi","Acum %n zile","Acum %n zile"],
    "last month" : "ultima lună",
    "_%n month ago_::_%n months ago_" : ["%n lună în urmă","%n luni în urmă","%n luni în urmă"],
    "last year" : "ultimul an",
    "_%n year ago_::_%n years ago_" : ["%n an în urmă","%n ani în urmâ","%n ani în urmâ"],
    "seconds ago" : "secunde în urmă",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulul cu id-ul %s nu există. Activează-l în setările tale de aplicație sau contactează-ți administratorul.",
    "Builtin" : "Inclus",
    "None" : "Niciuna",
    "Username and password" : "Nume de utilizator și parolă",
    "Username" : "Utilizator",
    "Password" : "Parolă",
    "Empty filename is not allowed" : "Nu este permis fișier fără nume",
    "Dot files are not allowed" : "Fișierele care încep cu caracterul punct nu sunt permise",
    "4-byte characters are not supported in file names" : "Caracterele stocate în 4 octeți nu sunt suportate în denumirile fișierelor",
    "File name is a reserved word" : "Numele fișierului este un cuvânt rezervat",
    "File name contains at least one invalid character" : "Numele fișierului conține măcar un caracter invalid",
    "File name is too long" : "Numele fișierului este prea lung",
    "App directory already exists" : "Directorul de aplicație există deja",
    "Can't create app folder. Please fix permissions. %s" : "Nu se poate crea directorul de aplicație. Repară permisiunile. %s",
    "Archive does not contain a directory named %s" : "Arhiva nu conține vreun director cu numele %s",
    "No source specified when installing app" : "Nu a fost specificată vreo sursă la instalarea aplicației",
    "No href specified when installing app from http" : "Nu s-a specificat adresa la instalarea aplicației dintr-o sursă de pe Internet",
    "No path specified when installing app from local file" : "Nu s-a specificat vreo cale la instalarea aplicației de pe un fișier local",
    "Archives of type %s are not supported" : "Arhivele de tip %s nu sunt suportate",
    "Failed to open archive when installing app" : "Deschiderea arhivei a eșuat în timpul instalării aplicației",
    "App does not provide an info.xml file" : "Aplicația nu furnizează un fișier info.xml",
    "App cannot be installed because appinfo file cannot be read." : "Aplicația nu poate fi instalată deoarece fișierul appinfo nu poate fi citit",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Semnătura nu a putut fi verificată. Contactează dezvoltatorul aplicației și verifică-ți consola administrativă.",
    "App can't be installed because of not allowed code in the App" : "Aplicația nu poate fi instalată deoarece conține cod nepermis",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplicația nu poate fi instalată deoarece nu este compatibilă cu această versiune ownCloud",
    "Apps" : "Aplicații",
    "General" : "General",
    "Storage" : "Stocare",
    "Security" : "Securitate",
    "Encryption" : "Încriptare",
    "Sharing" : "Partajare",
    "Search" : "Căutare",
    "Updates" : "Actualizări",
    "%s enter the database username and name." : "%s introdu numele de utilizator și parola pentru baza de date.",
    "%s enter the database username." : "%s introdu utilizatorul bazei de date.",
    "%s enter the database name." : "%s introduceți numele bazei de date",
    "Oracle connection could not be established" : "Conexiunea Oracle nu a putut fi stabilită",
    "Oracle username and/or password not valid" : "Numele de utilizator sau / și parola Oracle nu sunt valide",
    "DB Error: \"%s\"" : "Eroare Bază de Date: \"%s\"",
    "Offending command was: \"%s\"" : "Comanda cauză a fost: \"%s\"",
    "PostgreSQL username and/or password not valid" : "Nume utilizator și/sau parolă PostgreSQL greșită",
    "For the best results, please consider using a GNU/Linux server instead." : "Pentru cele mai bune rezultate, ia în calcul folosirea unui server care rulează un sistem de operare GNU/Linux.",
    "Set an admin username." : "Setează un nume de administrator.",
    "Set an admin password." : "Setează o parolă de administrator.",
    "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
    "%s shared »%s« with you" : "%s Partajat »%s« cu tine de",
    "%s via %s" : "%s via %s",
    "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
    "Sharing %s failed, because this item is already shared with %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu %s",
    "Not allowed to create a federated share with the same user" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Partajarea %s a eşuat, nu pot găsi %s, poate serverul nu poate fi contactat.",
    "Share type %s is not valid for %s" : "Tipul partajării %s nu este valid pentru %s",
    "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "The username is already being used" : "Numele de utilizator este deja folosit",
    "Help" : "Ajutor",
    "Settings" : "Setări",
    "Users" : "Utilizatori",
    "web services under your control" : "servicii web controlate de tine",
    "Application is not enabled" : "Aplicația nu este activată",
    "Authentication error" : "Eroare la autentificare",
    "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
    "Unknown user" : "Utilizator necunoscut",
    "Cannot write into \"config\" directory" : "Nu se poate scrie în folderul \"config\"",
    "Cannot write into \"apps\" directory" : "Nu se poate scrie în folderul \"apps\"",
    "PHP module %s not installed." : "Modulul PHP %s nu este instalat.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
    "PostgreSQL >= 9 required" : "Este necesară versiunea 9 sau mai mare a PostgreSQL",
    "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă",
    "A safe home for all your data" : "Un spațiu de stocare sigur pentru toate datele tale",
    "Imprint" : "Imprint",
    "__language_name__" : "_language_name_"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
